@@ -1,6 +1,7 @@
 # unittest_main_sub_engine3.py
 #
 # Copyright 2020 Ryota Higashi
+# Copyright 2021 Eiichi Inohira
 # This software may be modified and distributed under the terms
 # of the MIT license
 #
@@ -21,25 +22,12 @@ from datetime import datetime
 import json
 
 from pyrois import RoIS_HRI, RoIS_Common, RoIS_Service
-import HRI_Engine_sample, HRI_Engine_client_sample
-import command_message
-
-from component import System_Information
-from component import Person_Detection
-from component import Person_Localization
-from component import Person_Identification
-from component import Face_Detection
-from component import Face_Localization
-from component import Sound_Detection
-from component import Sound_Localization
-from component import Speech_Recognition
-from component import Gesture_Recognition
-from component import Speech_Synthesis
-from component import Reaction
-from component import Navigation
-from component import Follow
-from component import Move
-
+from pyrois_common import HRI_Engine_sample, HRI_Engine_client_sample
+from pyrois_common import command_message
+from pyrois_common import System_Information, Person_Detection, Person_Localization, Person_Identification
+from pyrois_common import Face_Detection, Face_Localization, Sound_Detection, Sound_Localization
+from pyrois_common import Speech_Recognition, Gesture_Recognition, Speech_Synthesis
+from pyrois_common import Reaction, Navigation, Follow, Move
 
 eng_profile = """<?xml version="1.0" encoding="UTF-8"?>
 <!-->
@@ -365,10 +353,12 @@ class Execute_test(unittest.TestCase):
         """ setUP
         """
         # start the server process
-        self.ps = [Process(target=HRI_Engine_sample.test_engine, args=(8016,"engine_profile_2_2", "client_info3", None, None,)),
-            Process(target=HRI_Engine_sample.test_engine, args=(8017,"engine_profile_2_2", "client_info3", "urn:x-rois:def:HRIEngine:Kyutech::sub01", None,)),
-            Process(target=HRI_Engine_sample.test_engine, args=(8018,"engine_profile_2_2", "client_info3", "urn:x-rois:def:HRIEngine:Kyutech::sub02", None,)),
-            Process(target=HRI_Engine_sample.test_engine, args=(8019,"engine_profile_2_2", "client_info3", "urn:x-rois:def:HRIEngine:Kyutech::sub03", None,)),
+        e_profile = "tests/engine_profile/engine_profile_2_2"
+        c_info = "tests/client_info/client_info3"
+        self.ps = [Process(target=HRI_Engine_sample.test_engine, args=(8016,e_profile, c_info, None, None,)),
+            Process(target=HRI_Engine_sample.test_engine, args=(8017,e_profile, c_info, "urn:x-rois:def:HRIEngine:Kyutech::sub01", None,)),
+            Process(target=HRI_Engine_sample.test_engine, args=(8018,e_profile, c_info, "urn:x-rois:def:HRIEngine:Kyutech::sub02", None,)),
+            Process(target=HRI_Engine_sample.test_engine, args=(8019,e_profile, c_info, "urn:x-rois:def:HRIEngine:Kyutech::sub03", None,)),
             
             Process(target=Person_Detection.example_pd, args=(8002,)),
             Process(target=Person_Identification.example_pi, args=(8004,)),
@@ -468,7 +458,7 @@ class Execute_test(unittest.TestCase):
             i.get_command_result("main-exe-1","")
         ]
             
-        print(res)
+        # print(res)
 
         s_e = set()
         completed_command_id = set()
@@ -498,7 +488,7 @@ class Execute_test(unittest.TestCase):
                                 command_ids.add(cl["command_id"])
 
         
-        print("set_parameter_command_ids:{}".format(command_ids))
+        # print("set_parameter_command_ids:{}".format(command_ids))
 
     
         res.extend([
@@ -542,23 +532,8 @@ class Execute_test(unittest.TestCase):
             if x.is_alive():
                 x.terminate()
 
-        time.sleep(1)
+        time.sleep(3)
 
 
 if __name__ == '__main__':
-    # ip = sys.argv
-    # if len(ip) > 1:
-    #     m = re.search(r'(\d+)\.(\d+)\.(\d+)\.(\d+)',ip[1])
-    # else:
-    #     m = None
-    # if m and len(m.groups()) == 4:
-    #     ser_uri = "http://" + ip[1] +":8000"
-    #     print("server_url == " + ser_uri + "\n")
-    #     del sys.argv[1]
-    # else:
-    #     ser_uri = "http://127.0.0.1:8000"
-    #     print("server_url == " + ser_uri + "\n")
-    #     if len(ip) > 1 and ip[1][0] != '-':
-    #         del sys.argv[1]
-
     unittest.main()
\ No newline at end of file
